==> micronaut-inject-1.0.4-sources.jar: io/micronaut/context/env/EmptyPropertySource.java <==
/*
 * Copyright 2017-2018 original authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.micronaut.context.env;

import java.util.Iterator;

/**
 * <p>An {@link PropertySource} that is empty when instantiated.</p>
 *
 * @author James Kleeh
 * @since 1.0
 */
public class EmptyPropertySource implements PropertySource {

    private final String name;

    /**
     * Default constructor. Creates an empty property source.
     */
    public EmptyPropertySource() {
        this("empty");
    }

    /**
     * Creates a property source with a name.
     *
     * @param name The name
     */
    public EmptyPropertySource(String name) {
        this.name = name;
    }

    @Override
    public String getName() {
        return name;
    }

    @Override
    public Object get(String key) {
        return null;
    }

    @Override
    public Iterator<String> iterator() {
        return new Iterator<String>() {
            @Override
            public boolean hasNext() {
                return false;
            }

            @Override
            public String next() {
                throw new UnsupportedOperationException("next");
            }
        };
    }
}

==> micronaut-inject-4.10.8-sources.jar: io/micronaut/context/env/EmptyPropertySource.java <==
/*
 * Copyright 2017-2020 original authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.micronaut.context.env;

import java.util.Iterator;

/**
 * <p>An {@link PropertySource} that is empty when instantiated.</p>
 *
 * @author James Kleeh
 * @since 1.0
 */
public class EmptyPropertySource implements PropertySource {

    private final String name;

    /**
     * Default constructor. Creates an empty property source.
     */
    public EmptyPropertySource() {
        this("empty");
    }

    /**
     * Creates a property source with a name.
     *
     * @param name The name
     */
    public EmptyPropertySource(String name) {
        this.name = name;
    }

    @Override
    public String getName() {
        return name;
    }

    @Override
    public Object get(String key) {
        return null;
    }

    @Override
    public Iterator<String> iterator() {
        return new Iterator<>() {
            @Override
            public boolean hasNext() {
                return false;
            }

            @Override
            public String next() {
                throw new UnsupportedOperationException("next");
            }
        };
    }
}
